@@ -1,7 +1,7 @@
 from django.db import models
 
 
-class TagField(models.Field):
+class TagField(models.TextField):
 
     def __init__(self, place_holder='', delimiters=' ', data_list=None,
                  suggestions_chars=1, black_list=None, max_tags=None, *args, **kwargs):
@@ -23,14 +23,14 @@ class TagField(models.Field):
         return self.to_python(value)
 
     def to_python(self, value):
-        value = super(TagField, self).to_python(value)
-        if isinstance(value, list):
+        if isinstance(value,list):
             return value
         if value is None:
             return []
         return value.split(self.delimiters)
 
     def get_db_prep_value(self, value, connection, prepared=False):
+
         return self.delimiters.join(value)
 
     def get_prep_value(self, value):
@@ -38,4 +38,8 @@ class TagField(models.Field):
 
     def formfield(self, **kwargs):
         from tagify.fields import TagField as FormTagField
-        return super().formfield(form_class=FormTagField, **self.tag_args)
+        return super(models.TextField,self).formfield(form_class=FormTagField, **self.tag_args)
+
+    def value_to_string(self, obj):
+        value = self.value_from_object(obj)
+        return self.get_prep_value(value)
\ No newline at end of file
