@@ -19,9 +19,12 @@ class TagInput(forms.TextInput):
         context['widget']['type'] = self.input_type
 
         context['widget']['tag_args'] = getattr(self, 'tag_args', None) or {'placeholder': 'write some tags',
-                                                                            'delimiters': ',',
+                                                                            'delimiters': ' ',
                                                                             'whitelist': [],
                                                                             'suggestionsMinChars': 1,
                                                                             'blacklist': [],
                                                                             'maxTags': None}
+        if isinstance(value, list):
+            context['widget']['value'] = context['widget']['tag_args']['delimiters'].join(value)
+
         return context
